Skip to main content Crate mkutils_macros Copy item path Source context tokio_main Example ConstAssoc Adds associated constants to a type via an inherent impl block. Constructor Adds a constructor that accepts each field as a parameter. Default Implements Default for a struct, using Default::default() for each field
unless a #[default(...)] attribute provides a custom expression. FromChain Implement ::std::convert::From through a chain of intermediate types. SaturatingAdd Implements num::traits::SaturatingAdd for a struct by delegating to each field.
Supports setting bounds with #[saturating_add(bound = "T: SomeTrait")] SaturatingAddSigned Implements mkutils::SaturatingAddSigned for a struct by delegating to each field.
Set the Signed associated type and bounds with
#[saturating_add_signed(assoc(type Signed = Point<<T as SaturatingAddSigned>::Signed>)), bound = "T: SomeTrait"] SaturatingSub Implements num::traits::SaturatingSub for a struct by delegating to each field.
Supports setting bounds with #[saturating_sub(bound = "T: SomeTrait")] SetVariant Adds set_*() methods for each unit variant on the given enum. Toggle Adds a toggled() method that maps each enum variant to the next unit variant. TypeAssoc Implements traits that only have associated types.